@@ -6,17 +6,15 @@ from typing import Optional, List, Type, Dict, Any
 
 import pandas as pd
 import streamlit as st
-
 import streamlit_pydantic as sp
 from bearish.models.base import Ticker  # type: ignore
 from bearish.models.price.prices import Prices  # type: ignore
 from bearish.models.query.query import AssetQuery, Symbols  # type: ignore
+from myportfolio.models import portfolio_optimize, PortfolioDescription  # type: ignore
+from mysec.services import sec  # type: ignore
+from pydantic import BaseModel
 from streamlit_file_browser import st_file_browser  # type: ignore
 
-from bullish.analysis.industry_views import get_industry_comparison_data
-from bullish.analysis.predefined_filters import PredefinedFilters
-from bullish.database.crud import BullishDb
-from bullish.figures.figures import plot
 from bullish.analysis.filter import (
     FilterQuery,
     FilterUpdate,
@@ -27,9 +25,12 @@ from bullish.analysis.filter import (
     GeneralFilter,
     TechnicalAnalysisFilters,
 )
+from bullish.analysis.industry_views import get_industry_comparison_data
+from bullish.analysis.portfolio import Portfolio, PortfolioAsset, PortfolioNewAsset
+from bullish.analysis.predefined_filters import PredefinedFilters
+from bullish.database.crud import BullishDb
+from bullish.figures.figures import plot
 from bullish.jobs.tasks import update, news, analysis, initialize
-from pydantic import BaseModel
-
 from bullish.utils.checks import (
     compatible_bearish_database,
     compatible_bullish_database,
@@ -80,7 +81,7 @@ def on_table_select() -> None:
 
     db = bearish_db(st.session_state.database_path)
     if st.session_state.data.empty or (
-        not st.session_state.data.iloc[row]["symbol"].to_numpy()
+        not st.session_state.data.iloc[row]["symbol"].to_numpy().size > 0
     ):
         return
 
@@ -123,7 +124,7 @@ def dialog_pick_database() -> None:
                 f"The database {db_path} has not the necessary data to run this application. "
                 "A backround job will be started to update the data."
             )
-            analysis(db_path)
+            analysis(db_path, "Update analysis")
         st.rerun()
     if event is None:
         st.stop()
@@ -232,6 +233,36 @@ def load() -> None:
             st.rerun()
 
 
+@st.dialog("📥  Load Portfolio", width="large")
+def load_portfolio() -> None:
+    bearish_db_ = bearish_db(st.session_state.database_path)
+    existing_portfolios = bearish_db_.read_portfolio_list()
+    option = st.selectbox("Select portfolio", ["", *existing_portfolios])
+    if option:
+        portfolio = bearish_db_.read_portfolio(option)
+        if portfolio:
+            st.session_state.portfolio = portfolio
+            st.rerun()
+
+
+@st.dialog("⭐ Save filtered results")
+def save_portfolio() -> None:
+    bearish_db_ = bearish_db(st.session_state.database_path)
+    portfolio_name = st.text_input("Portfolio name").strip()
+    apply = st.button("Apply")
+    if apply:
+        if not st.session_state.portfolio.default_name():
+            portfolio_name = f"{st.session_state.portfolio.name}_{portfolio_name}"
+        portfolio = Portfolio(
+            name=portfolio_name,
+            current_assets=st.session_state.portfolio.current_assets,
+            new_assets=st.session_state.portfolio.new_assets,
+            amount=st.session_state.portfolio.amount,
+        )
+        bearish_db_.write_portfolio([portfolio])
+        st.rerun()
+
+
 @st.dialog("🔍  Filter", width="large")
 def filter() -> None:
     with st.container(), st.expander("Predefined filters"):
@@ -405,7 +436,45 @@ def save_filtered_results(bearish_db_: BullishDb) -> None:
             st.rerun()
 
 
-def main() -> None:
+def portfolio_current_asset() -> None:
+    for i, row in enumerate(st.session_state.portfolio.current_assets):
+        left, middle, right = st.columns(3, vertical_alignment="bottom")
+        row.symbol = left.selectbox(
+            label="ticker", options=[row.symbol, *symbols()], key=f"input_{i}"
+        )
+        row.value = middle.number_input(
+            label="amount", value=row.value, key=f"number_{i}"
+        )
+        if right.button("🗑", key=f"del_{i}"):
+            st.session_state.portfolio.current_assets.pop(i)
+            st.rerun()
+    if st.button("➕", key="add_asset"):  # noqa: RUF001
+        st.session_state.portfolio.current_assets.append(
+            PortfolioAsset(symbol="", value=1000)
+        )
+        st.rerun()
+
+    if st.button("💾", key="save_asset"):
+        save_portfolio()
+
+
+def portfolio_new_assets() -> None:
+    left, right = st.columns(2, vertical_alignment="bottom")
+    symbols__ = [s.symbol for s in st.session_state.portfolio.new_assets]
+    symbols_ = left.multiselect(
+        label="ticker", default=symbols__, options=symbols(), key="new_input"
+    )
+    value = right.number_input(label="amount", value=1000, key="new_number")
+    if bool(symbols_) and value:
+        st.session_state.portfolio.new_assets = [
+            PortfolioNewAsset(symbol=s) for s in symbols_
+        ]
+        st.session_state.portfolio.amount = value
+    if st.button("💾", key="save"):
+        save_portfolio()
+
+
+def main() -> None:  # noqa: PLR0915, C901
     hide_elements = """
             <style>
                 div[data-testid="stSliderTickBarMin"],
@@ -417,6 +486,8 @@ def main() -> None:
 
     st.markdown(hide_elements, unsafe_allow_html=True)
     assign_db_state()
+    if "portfolio" not in st.session_state:
+        st.session_state.portfolio = Portfolio()
 
     if st.session_state.database_path is None:
         dialog_pick_database()
@@ -428,7 +499,9 @@ def main() -> None:
         st.session_state.initialized = True
     bearish_db_ = bearish_db(st.session_state.database_path)
 
-    charts_tab, jobs_tab = st.tabs(["Charts", "Jobs"])
+    charts_tab, portfolio_tab, jobs_tab, sec_tab = st.tabs(
+        ["Charts", "Portfolio", "Jobs", "Sec"]
+    )
     if "data" not in st.session_state:
         st.session_state.data = load_analysis_data(bearish_db_)
 
@@ -479,6 +552,28 @@ def main() -> None:
             use_container_width=True,
             hide_index=True,
         )
+    with sec_tab:
+        st.plotly_chart(sec(bearish_db_), use_container_width=True)
+    with portfolio_tab:
+        if st.button("📥", key="load_portfolio"):
+            load_portfolio()
+        with st.container():
+            with st.expander("Existing Assets"):
+                portfolio_current_asset()
+            with st.expander("New assets"):
+                portfolio_new_assets()
+        with st.container():
+            if (
+                st.button("Analyse", key="analyse_portfolio")
+                and st.session_state.portfolio.valid()
+            ):
+                figure = portfolio_optimize(
+                    bearish_db_,
+                    portfolio_description=PortfolioDescription.model_validate(
+                        st.session_state.portfolio.to_dict()
+                    ),
+                )
+                st.plotly_chart(figure, use_container_width=True)
 
 
 if __name__ == "__main__":
