@@ -4,6 +4,7 @@ from typing import Optional, Any, Callable, List
 
 import pandas as pd
 from bearish.main import Bearish  # type: ignore
+from bearish.models.sec.sec import Secs  # type: ignore
 from tickermood.main import get_news  # type: ignore
 from tickermood.types import DatabaseConfig  # type: ignore
 
@@ -83,7 +84,11 @@ def _base_update(
         bearish.update_prices(
             series_length=update_query.window_size,
             delay=update_query.data_age_in_days,
+            batch_size=update_query.batch_size,
+            pause=update_query.pause,
         )
+        bearish.get_prices_index(series_length=update_query.window_size)
+        Secs.upload(bearish._bearish_db)
         if update_query.update_financials:
             bearish.update_financials()
     bullish_db = BullishDb(database_path=database_path)
@@ -195,22 +200,20 @@ def news(
                 logger.debug(
                     f"extracting news for {symbol} subject: {subject.model_dump()}"
                 )
-                bullish_db.update_analysis(
-                    symbol,
-                    subject.model_dump(
-                        exclude_none=True,
-                        exclude_unset=True,
-                        exclude_defaults=True,
-                        exclude={"symbol"},
-                    ),
-                )
-    base_news(
-        database_path=database_path,
-        job_type=job_type,
-        symbols=symbols,
-        headless=headless,
-        task=task,
-    )
+                try:
+                    bullish_db.update_analysis(
+                        symbol,
+                        subject.model_dump(
+                            exclude_none=True,
+                            exclude_unset=True,
+                            exclude_defaults=True,
+                            exclude={"symbol"},
+                        ),
+                    )
+                except Exception as e:
+                    logger.error(f"failed to extract news for {symbol}: {e}")
+                    print(f"failed to extract news for {symbol}: {e}")
+                    continue
 
 
 @huey.periodic_task(crontab(minute="0", hour="8"), context=True)  # type: ignore
